@@ -1,6 +1,15 @@
 import asyncio
 from abc import abstractmethod, ABC
-from typing import Union, Type, TypeVar, Iterator, Optional, List, Generic, TYPE_CHECKING
+from typing import (
+    Union,
+    Type,
+    TypeVar,
+    Iterator,
+    Optional,
+    List,
+    Generic,
+    TYPE_CHECKING,
+)
 
 from sqlalchemy import and_, select, Table, exists, MetaData, func
 
@@ -15,7 +24,55 @@ MODEL = TypeVar('MODEL', bound='OrmModel')
 RELATION = TypeVar('RELATION', bound='_GenericIterableRelation')
 
 
-class _GenericIterableRelation(List[MODEL], ABC):
+class HashList(List[MODEL]):
+    map: dict
+
+    def __init__(self, items: Optional[List[MODEL]] = None):  # pylint: disable=unsubscriptable-object
+        self.map = {}
+        if items is not None:
+            super().__init__(items)
+            for i, x in enumerate(items):
+                self.map[x.pkey_value] = i
+        else:
+            super().__init__()
+
+    def add(self, other: MODEL):
+        if other.pkey_value in self.map:
+            return
+        self.append(other)
+        self.map[other.pkey_value] = len(self) - 1
+
+    def delete(self, other: MODEL):
+        if other.pkey_value not in self.map:
+            return
+        del self[self.map[other.pkey_value]]
+        del self.map[other.pkey_value]
+
+    def __contains__(self, item: Optional[Union[MODEL, int]]):  # pylint: disable=unsubscriptable-object
+        if item is None:
+            return False
+        if isinstance(item, int):
+            return item in self.map
+        return item.pkey_value in self.map
+
+    def __and__(self, other: 'HashList'):
+        result = []
+        for x in other:
+            if x.pkey_value in self.map:
+                result.append(x)
+        return result
+
+    def __or__(self, other: 'HashList'):
+        result = []
+        for x in other:
+            result.append(x)
+        for x in self:
+            if x.pkey_value not in other.map:
+                result.append(x)
+        return result
+
+
+class _GenericIterableRelation(ABC):
     # FoxOrm.init_relations() called, _from set, _to resolved to class
     _initialized: bool
     _from: 'Type[OrmModel]'
@@ -25,13 +82,12 @@ class _GenericIterableRelation(List[MODEL], ABC):
     _model: 'OrmModel'
     # Relation objects fetched
     _fetched: bool
-    _map: dict
+    _objects: HashList
 
     __modified__: dict
 
     def __init__(self):
-        super().__init__()
-        self._map = {}
+        self._objects = HashList()
         self.__modified__ = {}
         self._fetched = False
         self._initialized = False
@@ -60,19 +116,14 @@ class _GenericIterableRelation(List[MODEL], ABC):
     async def fetch(self) -> None:
         self._check_model_state()
         ids = await self.fetch_ids()
-
-        objects = await asyncio.gather(*[self.objects_type.get(x) for x in ids])
-        self._map = {}
-        self.clear()
-        self.extend(objects)
-        for i, x in enumerate(objects):
-            self._map[x.pkey_value] = i
-
+        self._objects = HashList(await asyncio.gather(*[self.objects_type.get(x) for x in ids]))
         self._fetched = True
 
     def _raise_if_not_initialized(self):
         if not self._initialized:
-            raise OrmException('Relation not initialized, call FoxOrm.init_relations() first')
+            raise OrmException(
+                'Relation not initialized, call FoxOrm.init_relations() first'
+            )
 
     def _check_model_state(self):
         assert self._copied
@@ -81,7 +132,9 @@ class _GenericIterableRelation(List[MODEL], ABC):
     def _raise_if_not_fetched(self):
         self._raise_if_not_initialized()
         if not self._fetched:
-            raise NotFetchedException('No values were fetched for this relation, first use .fetch_related()')
+            raise NotFetchedException(
+                'No values were fetched for this relation, first use .fetch_related()'
+            )
 
     @property
     def objects_type(self) -> Type[MODEL]:
@@ -93,12 +146,7 @@ class _GenericIterableRelation(List[MODEL], ABC):
         other.ensure_id()
         if not isinstance(other, self.objects_type):
             raise OrmException('other is not instance of target model')
-
-        if other.pkey_value in self._map:
-            return
-        self.append(other)
-        self._map[other.pkey_value] = super().__len__() - 1
-
+        self._objects.add(other)
         self.__modified__[other.pkey_value] = True
         return OptionalAwaitable(self.save)
 
@@ -107,22 +155,33 @@ class _GenericIterableRelation(List[MODEL], ABC):
         other.ensure_id()
         if not isinstance(other, self.objects_type):
             raise OrmException('other is not instance of target model')
-
-        if other.pkey_value not in self._map:
-            return
-        del self[self._map[other.pkey_value]]
-        del self._map[other.pkey_value]
-
+        self._objects.delete(other)
         self.__modified__[other.pkey_value] = False
         return OptionalAwaitable(self.save)
 
-    def __contains__(self, item: Union[MODEL, int]) -> bool:  # pylint: disable=unsubscriptable-object
+    def __contains__(
+        self, item: Union[MODEL, int]
+    ) -> bool:  # pylint: disable=unsubscriptable-object
         self._raise_if_not_fetched()
-        if item is None:
-            return False
-        if isinstance(item, int):
-            return item in self._map
-        return item.pkey_value in self._map
+        return item in self._objects
+
+    def __iter__(self) -> Iterator[MODEL]:
+        self._raise_if_not_fetched()
+        return self._objects.__iter__()
+
+    def __getitem__(self, item) -> MODEL:
+        self._raise_if_not_fetched()
+        return self._objects[item]
+
+    def __len__(self) -> int:
+        self._raise_if_not_fetched()
+        return len(self._objects)
+
+    def __bool__(self) -> int:
+        if not self._initialized:
+            return True
+        self._raise_if_not_fetched()
+        return bool(self._objects)
 
     def __and__(self, other: '_GenericIterableRelation') -> List[MODEL]:
         self._raise_if_not_fetched()
@@ -130,12 +189,7 @@ class _GenericIterableRelation(List[MODEL], ABC):
             raise OrmException('given parameter is not relation')
         if other.objects_type != self.objects_type:
             raise OrmException('given relation\'s objects type is incompatible with this relation\'s type')
-
-        result = []
-        for x in other:
-            if x.pkey_value in self._map:
-                result.append(x)
-        return result
+        return self._objects & other._objects
 
     def __or__(self, other: '_GenericIterableRelation') -> List[MODEL]:
         self._raise_if_not_fetched()
@@ -143,27 +197,29 @@ class _GenericIterableRelation(List[MODEL], ABC):
             raise OrmException('given parameter is not relation')
         if other.objects_type != self.objects_type:
             raise OrmException('given relation\'s objects type is incompatible with this relation\'s type')
-
-        result = []
-        for x in other:
-            result.append(x)
-        for x in self:
-            if x.pkey_value not in other._map:
-                result.append(x)
-        return result
+        return self._objects | other._objects
 
 
-class ManyToMany(_GenericIterableRelation):
+class ManyToMany(Generic[MODEL], _GenericIterableRelation):
     _via: Table
     _via_name: str
     _this_id: str
     _other_id: str
 
     async def _get_entry(self, other_id):
-        return await FoxOrm.db.fetch_val(select([exists().where(and_(
-            getattr(self._via.c, self._this_id) == self._model.pkey_value,
-            getattr(self._via.c, self._other_id) == other_id
-        ))]))
+        return await FoxOrm.db.fetch_val(
+            select(
+                [
+                    exists().where(
+                        and_(
+                            getattr(self._via.c, self._this_id)
+                            == self._model.pkey_value,
+                            getattr(self._via.c, self._other_id) == other_id,
+                        )
+                    )
+                ]
+            )
+        )
 
     # pylint: disable=unsubscriptable-object
     def __init__(self, to: Union[Type[MODEL], str], via: str):
@@ -175,8 +231,9 @@ class ManyToMany(_GenericIterableRelation):
         self._from = _from
         if isinstance(self._to, str):
             self._to = full_import(self._to)
-        self._via, self._this_id, self._other_id = \
-            FoxOrm.get_assoc_table(metadata, self._from, self._to, self._via_name)
+        self._via, self._this_id, self._other_id = FoxOrm.get_assoc_table(
+            metadata, self._from, self._to, self._via_name
+        )
         self._initialized = True
 
     # pylint: disable=protected-access
@@ -194,16 +251,21 @@ class ManyToMany(_GenericIterableRelation):
 
     async def fetch_ids(self) -> List[int]:
         self._check_model_state()
-        return [x[self._other_id] for x in await FoxOrm.db.fetch_all(self._via.select().where(
-            getattr(self._via.c, self._this_id) == self._model.pkey_value
-        ))]
+        return [
+            x[self._other_id]
+            for x in await FoxOrm.db.fetch_all(
+                self._via.select().where(
+                    getattr(self._via.c, self._this_id) == self._model.pkey_value
+                )
+            )
+        ]
 
     async def count(self) -> int:
         self._check_model_state()
         return await FoxOrm.db.fetch_val(
-            select([func.count()]).select_from(self._via).where(
-                getattr(self._via.c, self._this_id) == self._model.pkey_value
-            )
+            select([func.count()])
+            .select_from(self._via)
+            .where(getattr(self._via.c, self._this_id) == self._model.pkey_value)
         )
 
     async def save(self) -> None:
@@ -212,27 +274,44 @@ class ManyToMany(_GenericIterableRelation):
         for k, v in self.__modified__.items():
             entry_exists = await self._get_entry(k)
             if v and not entry_exists:
-                queries.append(FoxOrm.db.execute(self._via.insert(), {
-                    self._this_id: self._model.pkey_value,
-                    self._other_id: k
-                }))
+                queries.append(
+                    FoxOrm.db.execute(
+                        self._via.insert(),
+                        {self._this_id: self._model.pkey_value, self._other_id: k},
+                    )
+                )
             elif not v and entry_exists:
-                queries.append(FoxOrm.db.execute(self._via.delete().where(and_(
-                    getattr(self._via.c, self._this_id) == self._model.pkey_value,
-                    getattr(self._via.c, self._other_id) == k
-                ))))
+                queries.append(
+                    FoxOrm.db.execute(
+                        self._via.delete().where(
+                            and_(
+                                getattr(self._via.c, self._this_id)
+                                == self._model.pkey_value,
+                                getattr(self._via.c, self._other_id) == k,
+                            )
+                        )
+                    )
+                )
         await asyncio.gather(*queries)
         self.__modified__ = {}
 
 
-class OneToMany(_GenericIterableRelation):
+class OneToMany(Generic[MODEL], _GenericIterableRelation):
     key: str
 
     async def _get_entry(self, other_id):
-        return await FoxOrm.db.fetch_val(select([exists().where(and_(
-            getattr(self._to.c, self.key) == self._model.pkey_value,
-            self._to.pkey_column == other_id
-        ))]))
+        return await FoxOrm.db.fetch_val(
+            select(
+                [
+                    exists().where(
+                        and_(
+                            getattr(self._to.c, self.key) == self._model.pkey_value,
+                            self._to.pkey_column == other_id,
+                        )
+                    )
+                ]
+            )
+        )
 
     # pylint: disable=unsubscriptable-object
     def __init__(self, to: Union[Type[MODEL], str], key: str):
@@ -257,16 +336,21 @@ class OneToMany(_GenericIterableRelation):
 
     async def fetch_ids(self) -> List[int]:
         self._check_model_state()
-        return [x[self._to.__pkey_name__] for x in await FoxOrm.db.fetch_all(select([self._to.pkey_column]).where(
-            getattr(self._to.c, self.key) == self._model.pkey_value
-        ))]
+        return [
+            x[self._to.__pkey_name__]
+            for x in await FoxOrm.db.fetch_all(
+                select([self._to.pkey_column]).where(
+                    getattr(self._to.c, self.key) == self._model.pkey_value
+                )
+            )
+        ]
 
     async def count(self) -> int:
         self._check_model_state()
         return await FoxOrm.db.fetch_val(
-            select([func.count()]).select_from(self._to.__table__).where(
-                getattr(self._to.c, self.key) == self._model.pkey_value
-            )
+            select([func.count()])
+            .select_from(self._to.__table__)
+            .where(getattr(self._to.c, self.key) == self._model.pkey_value)
         )
 
     async def save(self) -> None:
@@ -275,17 +359,19 @@ class OneToMany(_GenericIterableRelation):
         for k, v in self.__modified__.items():
             entry_exists = await self._get_entry(k)
             if v and not entry_exists:
-                queries.append(FoxOrm.db.execute(self._to.__table__.update().where(
-                    self._to.pkey_column == k
-                ), {
-                    self.key: self._model.pkey_value
-                }))
+                queries.append(
+                    FoxOrm.db.execute(
+                        self._to.__table__.update().where(self._to.pkey_column == k),
+                        {self.key: self._model.pkey_value},
+                    )
+                )
             elif not v and entry_exists:
-                queries.append(FoxOrm.db.execute(self._to.__table__.update().where(
-                    self._to.pkey_column == k
-                ), {
-                    self.key: None
-                }))
+                queries.append(
+                    FoxOrm.db.execute(
+                        self._to.__table__.update().where(self._to.pkey_column == k),
+                        {self.key: None},
+                    )
+                )
         await asyncio.gather(*queries)
         self.__modified__ = {}
 
